aboutsummaryrefslogtreecommitdiffstats
path: root/lib/compiler/src/beam_ssa_bsm.erl
diff options
context:
space:
mode:
authorJohn Högberg <[email protected]>2019-06-28 09:14:43 +0200
committerJohn Högberg <[email protected]>2019-07-05 11:33:38 +0200
commita10fb1edf471602be01bd5b4c1f019cc5534b9f5 (patch)
tree588664b6b7019227a04494b88037be732238f918 /lib/compiler/src/beam_ssa_bsm.erl
parentec35aa92f49dedf4b25a78c6b8d56d629db6642d (diff)
downloadotp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.tar.gz
otp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.tar.bz2
otp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.zip
compiler: Explain and rename ?BADARG_BLOCK
Diffstat (limited to 'lib/compiler/src/beam_ssa_bsm.erl')
-rw-r--r--lib/compiler/src/beam_ssa_bsm.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/compiler/src/beam_ssa_bsm.erl b/lib/compiler/src/beam_ssa_bsm.erl
index 927a06edbf..7a8dc127d7 100644
--- a/lib/compiler/src/beam_ssa_bsm.erl
+++ b/lib/compiler/src/beam_ssa_bsm.erl
@@ -684,9 +684,9 @@ aca_copy_successors(Lbl0, Blocks0, Counter0) ->
Lbl = maps:get(Lbl0, BRs),
{Lbl, Blocks, Counter}.
-aca_cs_build_brs([?BADARG_BLOCK=Lbl | Path], Counter, Acc) ->
- %% ?BADARG_BLOCK is a marker and not an actual block, so renaming it will
- %% break exception handling.
+aca_cs_build_brs([?EXCEPTION_BLOCK=Lbl | Path], Counter, Acc) ->
+ %% ?EXCEPTION_BLOCK is a marker and not an actual block, so renaming it
+ %% will break exception handling.
aca_cs_build_brs(Path, Counter, Acc#{ Lbl => Lbl });
aca_cs_build_brs([Lbl | Path], Counter0, Acc) ->
aca_cs_build_brs(Path, Counter0 + 1, Acc#{ Lbl => Counter0 });